aboutsummaryrefslogtreecommitdiffstats
path: root/Library/Formula
diff options
context:
space:
mode:
Diffstat (limited to 'Library/Formula')
-rw-r--r--Library/Formula/python.rb4
-rw-r--r--Library/Formula/python3.rb4
2 files changed, 4 insertions, 4 deletions
diff --git a/Library/Formula/python.rb b/Library/Formula/python.rb
index e842ffae8..f462faf37 100644
--- a/Library/Formula/python.rb
+++ b/Library/Formula/python.rb
@@ -125,9 +125,9 @@ class Python < Formula
# Symlink the prefix site-packages into the cellar.
ln_s site_packages, site_packages_cellar
# We ship setuptools and pip and reuse the PythonInstalled
# Requirement here to write the sitecustomize.py
- py = PythonInstalled.new("2.7")
+ py = PythonDependency.new("2.7")
py.binary = bin/'python'
py.modify_build_environment
@@ -125,9 +125,9 @@ class Python < Formula
# Symlink the prefix site-packages into the cellar.
ln_s site_packages, site_packages_cellar
- # We ship setuptools and pip and reuse the PythonInstalled
+ # We ship setuptools and pip and reuse the PythonDependency
# Requirement here to write the sitecustomize.py
diff --git a/Library/Formula/python3.rb b/Library/Formula/python3.rb
index 506068d2e..54c20b3cc 100644
--- a/Library/Formula/python3.rb
+++ b/Library/Formula/python3.rb
@@ -138,9 +138,9 @@ class Python3 < Formula
# Make sure homebrew symlinks it to HOMEBREW_PREFIX/bin.
ln_s "#{bin}/python#{VER}", "#{bin}/python3" unless (bin/"python3").exist?
# We ship setuptools and pip and reuse the PythonInstalled
# Requirement here to write the sitecustomize.py
- py = PythonInstalled.new(VER)
+ py = PythonDependency.new(VER)
py.binary = bin/"python#{VER}"
py.modify_build_environment
@@ -138,9 +138,9 @@ class Python3 < Formula
# Make sure homebrew symlinks it to HOMEBREW_PREFIX/bin.
ln_s "#{bin}/python#{VER}", "#{bin}/python3" unless (bin/"python3").exist?
- # We ship setuptools and pip and reuse the PythonInstalled
+ # We ship setuptools and pip and reuse the PythonDependency
# Requirement here to write the sitecustomize.py